==> django_nimbus_api-3.0.2-py2.py3-none-any.whl: django_nimbus_api/__init__.py <==
# -*- coding: utf-8 -*-
from __future__ import absolute_import
from datetime import date

__all__ = [
    "__version__",
    "__description__",
    "__keywords__",
    "__author__",
    "__author_email__",
    "__url__",
    "__platforms__",
    "__license__",
    "__classifiers__",
    "__install_requires__",
    "__zip_safe__",
    "__copyright__",
]

__version__ = '3.0.2'
__description__ = "django_nimbus_api"
__keywords__ = ["django_nimbus_api", "nimbus", "django", "api"]
__author__ = "william"
__author_email__ = "william.ren@live.cn"
__maintainer__ = "william"
__maintainer_email__ = "william.ren@live.cn"
__url__ = "https://github.com/williamren"
__platforms__ = "Any"
__license__ = "Apache License 2.0"
__classifiers__ = [
    "Development Status :: 5 - Production/Stable",
    "Intended Audience :: Developers",
    "License :: OSI Approved :: Apache Software License",
    "Operating System :: MacOS :: MacOS X",
    "Operating System :: Microsoft :: Windows",
    "Operating System :: POSIX",
    "Programming Language :: Python",
    "Programming Language :: Python :: 2.7",
    "Programming Language :: Python :: 3",
    "Programming Language :: Python :: 3.3",
    "Programming Language :: Python :: 3.4",
    "Programming Language :: Python :: 3.5",
    "Programming Language :: Python :: 3.6",
    "Programming Language :: Python :: 3.7",
    "Topic :: Internet :: WWW/HTTP",
    "Environment :: Web Environment",
    "Framework :: Django",
    "Framework :: Django :: 1.8",
    "Framework :: Django :: 1.9",
    "Framework :: Django :: 1.10",
    "Framework :: Django :: 1.11",
]
__install_requires__ = [
    "Django",
    "djangorestframework",
    "pycrypto",
    "rncryptor",
    "python-dateutil",
    "nimbus_utils",
]
__zip_safe__ = False
__copyright__ = "Copyright 2001-{0} {1}".format(date.today().year, __author__)

==> django_nimbus_api-3.1.2-py2.py3-none-any.whl: django_nimbus_api/__init__.py <==
# -*- coding: utf-8 -*-
from __future__ import absolute_import
from datetime import date

__all__ = [
    "__version__",
    "__description__",
    "__keywords__",
    "__author__",
    "__author_email__",
    "__url__",
    "__platforms__",
    "__license__",
    "__classifiers__",
    "__install_requires__",
    "__zip_safe__",
    "__copyright__",
]

__version__ = '3.1.2'
__description__ = "django_nimbus_api"
__keywords__ = ["django_nimbus_api", "nimbus", "django", "api"]
__author__ = "william"
__author_email__ = "william.ren@live.cn"
__maintainer__ = "william"
__maintainer_email__ = "william.ren@live.cn"
__url__ = "https://github.com/williamren"
__platforms__ = "Any"
__license__ = "Apache License 2.0"
__classifiers__ = [
    "Development Status :: 5 - Production/Stable",
    "Intended Audience :: Developers",
    "License :: OSI Approved :: Apache Software License",
    "Operating System :: MacOS :: MacOS X",
    "Operating System :: Microsoft :: Windows",
    "Operating System :: POSIX",
    "Programming Language :: Python",
    "Programming Language :: Python :: 2.7",
    "Programming Language :: Python :: 3",
    "Programming Language :: Python :: 3.3",
    "Programming Language :: Python :: 3.4",
    "Programming Language :: Python :: 3.5",
    "Programming Language :: Python :: 3.6",
    "Programming Language :: Python :: 3.7",
    "Programming Language :: Python :: 3.8",
    "Programming Language :: Python :: 3.9",
    "Topic :: Internet :: WWW/HTTP",
    "Environment :: Web Environment",
    "Framework :: Django",
    "Framework :: Django :: 1.10",
    "Framework :: Django :: 1.11",
    "Framework :: Django :: 2.0",
    "Framework :: Django :: 3.0",
]
__install_requires__ = [
    "Django",
    "djangorestframework",
    "djangorestframework-jwt",
    "jwt",
    "pycrypto",
    "rncryptor",
    "python-dateutil",
    "coreapi",
    "nimbus_utils",
]
__zip_safe__ = False
__copyright__ = "Copyright 2001-{0} {1}".format(date.today().year, __author__)
